import 'dart:async';

import 'package:zego_express_engine/zego_express_engine.dart';
import 'package:zego_uikit/src/services/services.dart';

mixin ZegoUIKitCoreDataError {
  StreamController<ZegoUIKitError> errorStreamCtrl =
      StreamController<ZegoUIKitError>.broadcast();

  void onDebugError(int errorCode, String funcName, String info) {
    errorStreamCtrl.add(
      ZegoUIKitError(
        code: errorCode,
        message: info,
        method: 'express-debug:$funcName',
      ),
    );
  }

  void onFatalError(int errorCode) {
    errorStreamCtrl.add(
      ZegoUIKitError(
        code: errorCode,
        message: '',
        method: 'express-fatal',
      ),
    );
  }

  void onApiCalledResult(int errorCode, String funcName, String info) {
    if (ZegoErrorCode.CommonSuccess != errorCode) {
      errorStreamCtrl.add(
        ZegoUIKitError(
          code: errorCode,
          message: info,
          method: 'express-api:$funcName',
        ),
      );
    }
  }

  void onMobileScreenCaptureExceptionOccurred(
    ZegoScreenCaptureExceptionType exceptionType,
  ) {
    errorStreamCtrl.add(
      ZegoUIKitError(
        code: ZegoUIKitErrorCode.fromZegoScreenCaptureExceptionType(
          exceptionType,
        ),
        message: exceptionType.name,
        method: 'express-onMobileScreenCaptureExceptionOccurred',
      ),
    );
  }
}
